""" Example nester function """
from __future__ import print_function

def print_lol(the_list, level=0):
    for each_item in (the_list):
        if isinstance(each_item, list):
            print_lol(each_item, level+1)
        else:
            for tab_stop in range(level):
                print("\t", end='')
            print(each_item)
            



from distutils.core import setup

setup(
    name = 'pm-nester',
    version = '1.1.0',
    py_modules = ['pm-nester'],
    author = 'pmodali',
    author_email = 'prasad.modali@yahoo.com',
    url = '',
    description = 'Simple printer of nested lists',
    )
